==> maven-mrpopo-plugin-1.0.2-sources.jar: org/walkmod/mrpopo/mojos/MrPopoMojo.java <==
package org.walkmod.mrpopo.mojos;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.Iterator;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.codehaus.jackson.JsonNode;
import org.codehaus.jackson.JsonParser.Feature;
import org.codehaus.jackson.map.ObjectMapper;

@Mojo(name = "mrpopo")
public class MrPopoMojo extends AbstractMojo {

	/**
	 * popo url
	 */
	@Parameter
	protected String url = null;

	public String getCommit() throws MojoExecutionException,
			MojoFailureException {
		String commit = null;
		File head = new File(".git/logs", "HEAD");
		FileReader reader = null;
		BufferedReader br = null;
		if (!head.exists()) {
			throw new MojoExecutionException("This is not a Git repository");
		}
		try {
			reader = new FileReader(head);
			br = new BufferedReader(reader);
			String line = br.readLine();
			String currentLine = line;
			while (currentLine != null && currentLine.length() > 0) {
				line = currentLine;
				currentLine = br.readLine();
			}
			// line contains the last commit
			String parts[] = line.split(" ");
			commit = parts[1];

		} catch (Exception e) {
			MojoExecutionException ex = new MojoExecutionException(
					"Error reading the .git/logs/HEAD file", e);
			throw ex;

		} finally {
			if (br != null) {
				try {
					br.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the buffer", e);
					throw ex;
				}
			}
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the reader", e);
					throw ex;
				}
			}
		}
		return commit;
	}

	public String getReference() throws MojoExecutionException,
			MojoFailureException {
		File head = new File(".git", "HEAD");
		FileReader reader = null;
		BufferedReader br = null;
		String reference = null;
		if (!head.exists()) {
			throw new MojoExecutionException("This is not a Git repository");
		}
		try {
			reader = new FileReader(head);
			br = new BufferedReader(reader);
			String line = br.readLine();
			if (line.length() > 0) {
				String[] parts = line.split(":");
				if (parts.length == 2) {
					parts[1] = parts[1].trim();
					if (parts[1].startsWith("refs/heads/")) {
						reference = parts[1];
					} else {
						throw new MojoExecutionException("Invalid Ref");
					}
				} else {
					return null;
				}

			}
		} catch (Exception e) {
			MojoExecutionException ex = new MojoExecutionException(
					"Error reading the .git/HEAD file", e);
			throw ex;

		} finally {
			if (br != null) {
				try {
					br.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the buffer", e);
					throw ex;
				}
			}
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the reader", e);
					throw ex;
				}
			}
		}
		return reference;
	}

	public String getRemote() throws MojoExecutionException,
			MojoFailureException {

		String remote = null;
		File config = new File(".git", "config");
		if (!config.exists()) {
			throw new MojoExecutionException(
					"The .git/config file does not exist");
		}
		FileReader reader = null;
		BufferedReader br = null;

		try {
			reader = new FileReader(config);
			br = new BufferedReader(reader);
			String line = br.readLine();
			boolean finish = line == null;
			while (!finish) {
				String cleanLine = line.trim();
				if (cleanLine.startsWith("url = ")) {
					finish = true;
					remote = cleanLine.substring("url = ".length());
				}
				line = br.readLine();
				finish = finish || line == null;
			}

		} catch (Exception e) {
			MojoExecutionException ex = new MojoExecutionException(
					"Error reading the .git/HEAD file", e);
			throw ex;

		} finally {
			if (br != null) {
				try {
					br.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the buffer", e);
					throw ex;
				}
			}
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the reader", e);
					throw ex;
				}
			}
		}
		return remote;
	}

	public boolean conventionsApplied(InputStream is) throws IOException {
		boolean conventionsApplied = false;
		ObjectMapper mapper = new ObjectMapper();
		mapper.configure(Feature.ALLOW_UNQUOTED_FIELD_NAMES, true);
		JsonNode response = mapper.readTree(is);
		JsonNode files = response.get("files");

		if (files.isArray()) {
			Iterator<JsonNode> it = files.getElements();

			conventionsApplied = it.hasNext();
			if (conventionsApplied) {
				System.out.println("=====================================");
			}
			while (it.hasNext()) {
				getLog().info(it.next().asText());
			}
			if (conventionsApplied) {
				System.out.println("=====================================");
			}
		}
		return conventionsApplied;
	}

	public void execute() throws MojoExecutionException, MojoFailureException {

		if (url == null) {
			throw new MojoExecutionException("The url parameter is null");
		}
		String reference = getReference();
		String remote = getRemote();
		String commit = getCommit();
		InputStream is = null;
		boolean conventionsApplied = false;
		String fullURL = url += "?remote=" + remote;
		if (reference != null) {
			fullURL += "&&reference=" + reference;
		}

		fullURL += "&&commit=" + commit;

		try {
			URL address = new URL(fullURL);
			is = address.openStream();
			conventionsApplied = conventionsApplied(is);

		} catch (Exception e) {
			throw new MojoExecutionException(
					"Error reading the mrpopo response", e);
		} finally {

			if (is != null) {
				try {
					is.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the input stream", e);
					throw ex;
				}
			}
		}
		if (conventionsApplied) {
			throw new MojoFailureException(
					"There are conventions violated. The next build will be automatically fixed");
		}
	}
}

==> maven-mrpopo-plugin-1.0.5-sources.jar: org/walkmod/mrpopo/mojos/MrPopoMojo.java <==
package org.walkmod.mrpopo.mojos;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.Iterator;
import java.util.Map;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.codehaus.jackson.JsonNode;
import org.codehaus.jackson.JsonParser.Feature;
import org.codehaus.jackson.map.ObjectMapper;
import org.eclipse.jgit.api.Git;
import org.eclipse.jgit.lib.ObjectId;
import org.eclipse.jgit.lib.Ref;
import org.eclipse.jgit.lib.Repository;
import org.eclipse.jgit.lib.StoredConfig;

@Mojo(name = "mrpopo")
public class MrPopoMojo extends AbstractMojo {

	/**
	 * popo url
	 */
	@Parameter
	protected String url = null;

	public String getCommit() throws MojoExecutionException,
			MojoFailureException {
		String commit = null;
		File head = new File(".git", "HEAD");
		FileReader reader = null;
		BufferedReader br = null;
		if (!head.exists()) {
			throw new MojoExecutionException("This is not a Git repository");
		}
		try {
			reader = new FileReader(head);
			br = new BufferedReader(reader);
			String line = br.readLine();
			int index = line.indexOf(":");
			if (index == -1) {
				commit = line;
			} else {
				String refName = line.substring(index + 1).trim();
				File ref = new File(".git", refName);
				BufferedReader refReader = new BufferedReader(new FileReader(
						ref));
				try {
					commit = refReader.readLine().trim();
				} finally {
					refReader.close();
				}

			}

		} catch (Exception e) {
			MojoExecutionException ex = new MojoExecutionException(
					"Error reading the .git/logs/HEAD file", e);
			throw ex;

		} finally {
			if (br != null) {// git branch --contains 97cb072
				try {
					br.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the buffer", e);
					throw ex;
				}
			}
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the reader", e);
					throw ex;
				}
			}
		}
		return commit;
	}

	public String getReference() throws MojoExecutionException,
			MojoFailureException {
		File gitWorkDir = new File(".");

		String reference = null;
		try {
			Git git = Git.open(gitWorkDir);
			Repository repo = git.getRepository();
			String branch = repo.getFullBranch();
			if (branch.startsWith("ref")) {
				reference = branch;
			} else {
				reference = getRefFromCommit(branch);
			}
		} catch (IOException e) {
			throw new MojoExecutionException("Error resolving the branch ", e);
		}

		return reference;
	}

	public String getRefFromCommit(String commit) throws IOException {
		File gitWorkDir = new File(".");
		Git git = Git.open(gitWorkDir);
		Repository repo = git.getRepository();
		Map<String, Ref> references = repo.getAllRefs();
		ObjectId object = repo.resolve(commit);
		Iterator<String> it = references.keySet().iterator();
		boolean found = false;
		String reference = "";
		while (it.hasNext() && !found) {
			String ref = it.next();
			if (ref.startsWith("refs/heads")) {
				found = repo.getReflogReader(ref).getLastEntry().getNewId()
						.equals(object);
				if (found) {
					reference = ref;
				}
			}
		}
		return reference;
	}

	public String getRemote() throws MojoExecutionException,
			MojoFailureException {
		File gitWorkDir = new File(".");
		String url = null;
		StoredConfig config = null;
		try {
			Git git = Git.open(gitWorkDir);
			Repository repo = git.getRepository();
			config = repo.getConfig();

		} catch (IOException e) {
			throw new MojoExecutionException("Error resolving the branch ", e);
		}
		url = config.getString("remote", "origin", "url");
		int index = url.indexOf("github.com");
		if (index == -1) {

			throw new MojoExecutionException("The url must belong to Github");
		}

		return url;
	}

	public boolean conventionsApplied(InputStream is) throws IOException {
		boolean conventionsApplied = false;
		ObjectMapper mapper = new ObjectMapper();
		mapper.configure(Feature.ALLOW_UNQUOTED_FIELD_NAMES, true);
		JsonNode response = mapper.readTree(is);
		JsonNode files = response.get("files");

		if (files != null && files.isArray()) {
			Iterator<JsonNode> it = files.getElements();

			conventionsApplied = it.hasNext();
			if (conventionsApplied) {
				System.out.println("=====================================");
			}
			while (it.hasNext()) {
				getLog().info(it.next().asText());
			}
			if (conventionsApplied) {
				System.out.println("=====================================");
			}
		}
		return conventionsApplied;
	}

	public void execute() throws MojoExecutionException, MojoFailureException {

		if (url == null) {
			throw new MojoExecutionException("The url parameter is null");
		}
		String reference = getReference();
		String remote = getRemote();
		String commit = getCommit();
		InputStream is = null;
		boolean conventionsApplied = false;
		String fullURL = url += "?remote=" + remote;
		fullURL += "&&reference=" + reference;
		fullURL += "&&commit=" + commit;

		try {
			URL address = new URL(fullURL);
			is = address.openStream();
			conventionsApplied = conventionsApplied(is);

		} catch (Exception e) {
			throw new MojoExecutionException(
					"Error reading the mrpopo response", e);
		} finally {

			if (is != null) {
				try {
					is.close();
				} catch (IOException e) {
					MojoExecutionException ex = new MojoExecutionException(
							"Error closing the input stream", e);
					throw ex;
				}
			}
		}
		if (conventionsApplied) {
			throw new MojoFailureException(
					"There are conventions violated. The next build will be automatically fixed");
		}
	}
}
